**Example 1: 查看镜像仓库资产更新进度状态**



Input: 

```
tccli tcss DescribeAssetImageRegistryAssetStatus --cli-unfold-argument ```

Output: 
```
{
    "Response": {
        "RequestId": "33ec689a-e026-4700-8dc4-b559b97f0667",
        "Status": "doing",
        "Err": "xx"
    }
}
```

